#!/bin/sh
#
# code by ngc1927

rm -f /var/bin/openvpn
rm -f /var/bin/scrplg-Start_Openvpn.sh
rm -f /var/bin/scrplg-Stop_Openvpn.sh

rm -f /var/doc/openvpn.readme

rm -rf /var/etc/openvpn

#rm -f /var/lib/modules/tun.ko

rm -f /var/etc/SifTeam/tmp/settable.system/Start-Openvpn_script.sh
rm -f /var/etc/SifTeam/tmp/settable.system/Stop-Openvpn_script.sh

rm -f /var/etc/SifTeam/bin/S80openvpn.sh

rm -f /var/lib/libcrypto.so.4
rm -f /var/lib/libcom_err.so
rm -f /var/lib/libcom_err.so.2
rm -f /var/lib/libcom_err.so.3
rm -f /var/lib/libcom_err.so.3.0
rm -f /var/lib/libgssapi_krb5.so
rm -f /var/lib/libgssapi_krb5.so.2
rm -f /var/lib/libgssapi_krb5.so.2.2
rm -f /var/lib/libk5crypto.so
rm -f /var/lib/libk5crypto.so.3
rm -f /var/lib/libk5crypto.so.3.0
rm -f /var/lib/libkrb5.so
rm -f /var/lib/libkrb5.so.3
rm -f /var/lib/libkrb5.so.3.1
rm -f /var/lib/libssl.so
rm -f /var/lib/libssl.so.0
rm -f /var/lib/libssl.so.0.9.7
rm -f /var/lib/libssl.so.4
rm -f /var/lib/liblzo.so.1.0.0
rm -f /var/lib/liblzo.so.1


rm -f /var/uninstall/openvpn-2.0.9-r7_delfile.sh

exit 0
